@@ -1,7 +1,7 @@
 from starlette.responses import Response
 from urllib.parse import quote_plus
 import typing
-import json
+import ujson
 
 
 class TextResponse(Response):
@@ -21,7 +21,7 @@ class JSON(Response):
     media_type = "application/json"
 
     def render(self, content: typing.Any) -> bytes:
-        return json.dumps(
+        return ujson.dumps(
             content,
             ensure_ascii=False,
             allow_nan=False,
